@@ -1,4 +1,5 @@
 import os
+import sys
 
 import pytest
 
@@ -7,7 +8,8 @@ def main():
     # run in test directory
     os.chdir(os.path.dirname(os.path.abspath(__file__)))
 
-    pytest.main()
+    code = pytest.main()
+    sys.exit(code)
 
 
 if __name__ == '__main__':
